@@ -33,7 +33,7 @@ stream.lst_mdl <- function(object, new_data, ...){
 stream.mdl_ts <- function(object, new_data, ...){
   # Compute specials with new_data
   object$model$add_data(new_data)
-  specials <- parse_model_rhs(object$model)$specials
+  specials <- parse_model_rhs(object$model)
   object$model$remove_data()
   
   object$fit <- stream(object[["fit"]], new_data, specials = specials, ...)
